/*
 * Copyright 2002 Sun Microsystems, Inc.
 * Property of Sun Microsystems, Inc.
 */

package sample;

import com.sun.im.desktop.*;
import com.sun.im.service.*;


/**
 * implementation of a Sun Messenger extension
 * This is the interface that an extension provider implements
 * in order to be invoked by the messenger application
 * A Messenger extension is invoked through a UI component
 * which may take one several forms, including a button, a
 * pull down or menu option.
 */
public class SampleBean extends MessengerBeanFactory implements MessengerMessageListener 
{
    
    MessengerAppContext _appContext = null;

    public void onMessage(ReadOnlyMessage message)
    {
	try {
	    System.out.println("NEW MESSAGE");
	    System.out.println("Content-Type: " + message.getContentType());
	    System.out.println("Subject: " + message.getHeader("subject"));
	    System.out.println(message.getContent());
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }

    public void init()
    {
	try {
	    _appContext = MessengerAppContext.getAppContext();
	    System.out.println("CALLING addMessageListener");	
	    _appContext.addMessageListener(this);
	    System.out.println("CALLED addMessageListener");	
	    System.out.println("[SampleBean] user id: " + _appContext.getProperty("uid"));	
	    System.out.println("[SampleBean] sso token: " + _appContext.getProperty("token"));		    
	} catch (MessengerException e) {
	    e.printStackTrace();
	}
    }

    class SampleBeanActionListener extends MessengerActionListener implements MessengerConferenceListener {
        MessengerConferenceContainer _container;
        
        public SampleBeanActionListener(MessengerConferenceContainer container) {
            _container = container;
            _container.addConferenceListener(this);
        }
        
        /**
         * returns the label to be associated with the swing component
         * used to invoke the extension (Button, option, etc..).
         */
        public String getLabel() {
            return "Google";
        }
        
        public void actionPerformed(java.awt.event.ActionEvent event) {
            System.out.println("### SampleBean invoked for " + _appContext.getUserId());
            try {
                _container.addTextMessage("Everyone search <a href=\"http://www.google.com\">Google</a> !");
            } catch (MessengerException e) {
                e.printStackTrace();
            }
        }
        
        /**
         * invoked when a text message is received by the container
         * @param user ID (aka IM address) of the originator  of the message
         * @param text text of the message, plain or HTML
         */
        public void onTextMessageAdded(String uid, String text) {
            System.out.println("### " + _appContext.getDisplayName(uid) + " writes: " + text);
        }
        
        /**
         * invoked when a new participant joins the conference or an existing
         * participant leaves the conference
         * @param uid participant user id (aka IM address)
         * @param displayName participant display name
         * @param true if this is a new participant, false if this is a
         * participant leaving.
         */
        public void onEvent(String uid, boolean join) {
            if (join) {
                System.out.println("### " + _appContext.getDisplayName(uid) + " has joined.");
            } else {
                System.out.println("### " + _appContext.getDisplayName(uid) + " has left.");
            }
        }
        
        
    }
    
    /**
     * provides the AWT event listener to be registered with the
     * invoking component.  The specified action listener is invoked
     * when the user activates one of the component used to invoke
     * the extension.
     * @param container container from which the extension was invoked
     * @return action listener or null if the functionality is disabled.
     */
    public MessengerEventListener getEventListener(MessengerContainer container) {
        if (container instanceof MessengerConferenceContainer) {
            return new SampleBeanActionListener((MessengerConferenceContainer)container);
        } else {
            return null;
        }
    }
    
    /**
     * invoked by the application when the context in which an
     * action listener has been created is being destroyed.  It is important
     * that all references to the listener or the associated context
     * be eliminated in order to avoid memory leaks.
     * @param listener listener to be removed.
     */
    public void removeEventListener(MessengerEventListener listener) {
        // todo remove reference to container
    }
    
    //    public boolean isEnabled();
    
        /**
     * tell the messenger where the bean should show up
     * Example: If a bean adds functionality to the chat and poll/receive
     * window, this method should return
     *  MBEAN_LOCATION_CHAT | MBEAN_LOCATION_RECEIVE_POLL
     * @return bitwise OR of all locations/windows impacted by this
     * bean
     */
    public int getLocations() {
        return MBEAN_LOCATION_CONFERENCE | MBEAN_LOCATION_CHAT;
    }
    

}
